const path = require('path');
const { URL } = require('url');
const glob = require('glob');
const { injectScript } = require('./inject-script');
const { removeHeaders } = require('./remove-headers');

module.exports = {
  async onPreBuild({ constants: { CONFIG_PATH, PUBLISH_DIR } }) {
    // only enable deploy preview commenting for deploy previews
    if (process.env.CONTEXT !== 'deploy-preview') {
      return;
    }

    // remove iframe security headers so DPC works
    const headersFilePath = path.join(PUBLISH_DIR, '_headers');
    const tomlFilePath = CONFIG_PATH;

    removeHeaders(headersFilePath);
    removeHeaders(tomlFilePath);
  },
  async onPostBuild({ constants: { PUBLISH_DIR }, utils }) {
    // only enable deploy preview commenting for deploy previews
    if (process.env.CONTEXT !== 'deploy-preview') {
      return;
    }

    // add the DPC script to all HTML files
    const files = glob.sync(`${PUBLISH_DIR}/**/*.html`);
    const promises = files.map(injectScript);

    await Promise.all(promises);

    const url = new URL(process.env.DEPLOY_PRIME_URL);
    const [subdomain] = url.hostname.split('.');
    const dpcURL = `https://netlify-dpc.netlify.app/${subdomain}/`;

    utils.status.show({
      title: 'Deploy Preview Commenting enabled!',
      summary: `View and discuss at ${dpcURL}`,
    });
  },
};
