const fs = require('fs');
const parseGitHub = require('parse-github-repo-url');
const unified = require('unified');
const parse = require('rehype-parse');
const visit = require('unist-util-visit');
const h = require('hastscript');
const stringify = require('rehype-stringify');

const [owner, repo] = parseGitHub(process.env.REPOSITORY_URL);
const info = {
  netlify_prime_url: process.env.DEPLOY_PRIME_URL,
  pull_request_id: process.env.REVIEW_ID,
  owner,
  repo,
};

const hash = Buffer.from(JSON.stringify(info)).toString('base64');

const addScriptNode = () => (tree) => {
  visit(tree, 'element', (node) => {
    if (node.tagName === 'body') {
      node.children.push(h('script', `window.___NETLIFY_DPC___="${hash}"`));
      node.children.push(
        h('script', { src: 'https://dpcbp.netlify.app/netlify-dpc.js' }),
      );
    }
  });
};

exports.injectScript = (filePath) =>
  new Promise((resolve) => {
    try {
      const markup = unified()
        .use(parse)
        .use(addScriptNode)
        .use(stringify)
        .processSync(fs.readFileSync(filePath))
        .toString();

      fs.writeFileSync(filePath, markup);
    } catch (error) {
      console.error(`error injecting script into ${filePath}`);
      console.error(error.message);
    }

    resolve(true);
  });
